import React, { useEffect, useState } from "react";
import QRScanner from "../QRScanner";
import { useParams } from "react-router-dom";
import axios from "axios";
import apiData from "../../API/api";
import { DetailsSection, EventSection } from "./DataInfo";

const Data = () => {
  const [registration, setRegistration] = useState([]);
  const [events, setEvents] = useState([]);
  const [err, setErr] = useState(null);
  const [succ, setSucc] = useState(null);

  const params = useParams().data;

  const fetchData = async () => {
    try {
      const response = await axios.get(
        `http://65.20.69.67/api/${params}/userevents`
      );

      if (response?.data) {
        console.log("---response---->", response);
        setEvents(response.data.events);
        setRegistration(response.data);
      } else {
        setErr("Please try again");
      }
    } catch (error) {
      setErr("Error fetching data. Please try again.");
    }
  };

  const checkIn = (eventId) => {
    const apiEndpoint =
      eventId === 1 || eventId === 2
        ? `${params}/${eventId}/audit-reg`
        : `${params}/${eventId}/confirm`;

    apiData(apiEndpoint)
      .then((res) => {
        if (res.status === 200) {
          setSucc("Checked in successfully");
          setErr(null);
          fetchData();
        } else {
          setErr("Some problem occurred. Please try again.");
          setSucc(null);
        }
      })
      .catch((e) => {
        setErr("Some problem occurred. Please try again.");
        setSucc(null);
      });
  };

  useEffect(() => {
    if (params) {
      fetchData();
    }
  }, [params]);

  return (
    <>
      <h1 className="text-center headingEveFont">Anubhuti Events</h1>
      <QRScanner />
      <div className="d-flex align-items-center justify-content-center mt-4">
        <div className="row">
          <div className="col-lg-12">
            {params && (
              <>
                <h3>Details</h3>
                <DetailsSection data={registration} />
                <h6 className="text-center text-danger mt-4">
                  {err ? err : " "}
                </h6>
                <h6 className="text-center text-success mt-4">
                  {succ ? succ : " "}
                </h6>
                <div className="d-flex align-items-center justify-content-center mt-2">
                  <div className="row">
                    <div className="col-lg-12">
                      <h3>Events</h3>
                      <EventSection data={events} checkIn={checkIn} />
                    </div>
                  </div>
                </div>
              </>
            )}
          </div>
        </div>
      </div>
    </>
  );
};

export default Data;
