import React, { useState, useEffect } from "react";
import QrReader from "react-qr-scanner";
import { useNavigate } from "react-router-dom";
import "webrtc-adapter";

const QRScanner = () => {
  const navigate = useNavigate();
  const [showQR, setShowQR] = useState(false);

  useEffect(() => {
    if (!navigator.mediaDevices || !navigator.mediaDevices.getUserMedia) {
      console.error("getUserMedia is not supported in this browser");
    }
  }, []);

  const toggleQRDisplay = () => {
    setShowQR((prevShowQR) => !prevShowQR);
  };

  const handleScan = (data) => {
    if (data) {
      console.log("---data-text---->", data?.text);
      navigate(`/attendance/${data?.text}`);
    }
  };

  const handleError = (err) => {
    console.error("---error----->", err);
  };

  return (
    <div className="text-center">
      <button className="btnNeu" onClick={toggleQRDisplay}>
        {showQR ? "Close QR Scanner" : "Open QR Scanner"}
      </button>
      {showQR && (
        <div style={{ width: "95%", padding: "20px" }}>
          <QrReader
            style={{ width: "80%", height: "350px" }}
            constraints={{
              video: {
                facingMode: {
                  exact: "environment",
                },
              },
            }}
            delay={300}
            onError={handleError}
            onScan={handleScan}
          />
        </div>
      )}
    </div>
  );
};

export default QRScanner;
